@@ -31,7 +31,7 @@ from framework.utils.common import snake_to_pascal, get_apps, convert_numbers_to
 
 all_app = get_apps()
 module = importlib.import_module("test_case.conftest")
-MARK_LIST = [item for sublist in settings.MARK_LIST.values() for item in sublist]
+MARK_LIST = [item.lower() for sublist in settings.MARK_LIST.values() for item in sublist]
 
 
 @pytest.fixture(autouse=True)
@@ -154,6 +154,13 @@ def find_data_path_by_case(app, case_file_name):
             return file_path
 
 
+def subset_and_diff(small: set, big: set):
+    """
+    判断 small 是否为 big 的子集，并返回差集
+    """
+    return small.issubset(big), small - big
+
+
 def disable_field(scenario, data):
     if not scenario:
         return data
@@ -286,25 +293,6 @@ def pytest_configure(config):
     CONTEXT.set(key="all_app", value=all_app)
     sys.path.append(settings.CASES_DIR)
 
-    app = CONTEXT.get("app")
-    app_handlers = getattr(settings, "APP_START_HANDLER_CLASSES", {})
-    if app:
-        handlers = app_handlers.get(app) or []
-    else:
-        handlers = [h for value in app_handlers.values() for h in value] or []
-    global_handlers = getattr(settings, "GLOBAL_START_HANDLER_CLASSES", [])
-    global_handlers.extend(handlers)
-    handlers = global_handlers
-    for handler in handlers:
-        try:
-            module_path, class_name = handler.rsplit(".", 1)
-            cls = getattr(importlib.import_module(module_path), class_name)
-            cls().run()
-        except Exception as e:
-            logger.error(str(e))
-            traceback.print_exc()
-            pytest.exit(ExitCode.GLOBAL_SCRIPT_ERROR)
-
 
 def pytest_unconfigure(config):
     app = CONTEXT.get("app")
@@ -367,10 +355,18 @@ def pytest_generate_tests(metafunc):
         return
     # 获取mark标记
     marks = case_common.get("marks", [])
-    if not set(m.lower() for m in marks).issubset(m.lower() for m in MARK_LIST):
-        logger.warning(f"{func_name} 使用非规范的用例标签:{marks}")
-        if settings.STRICT_MARKS:
-            return
+    # 将case_common中的moudel加到标签中
+    marks.append(case_common.get("module", ""))
+    # 将脚本中类中和定义的标签加到marks
+    cls_pytestmark = getattr(metafunc.cls, "pytestmark", [])
+    func_pytestmark = getattr(metafunc.definition, "own_markers")
+    func_pytestmark.extend(cls_pytestmark)
+    for mark_obj in func_pytestmark:
+        if mark_obj.name not in ["skip", "skipif", "xfail", "usefixtures", "filterwarnings",
+                                 "parametrize", "order", "timeout", "django_db", "asyncio"] and not mark_obj.args:
+            marks.append(mark_obj.name)
+    # 校验标签
+    is_subset, diff = subset_and_diff(set(marks), set(MARK_LIST))
 
     # 测试用例数据
     case_data = test_data.get(func_name) or dict()
@@ -436,10 +432,7 @@ def pytest_generate_tests(metafunc):
                 continue
             scenario = item.get("scenario")
             level = scenario.get("level", settings.DEFAULT_CASE_LEVEL).lower()
-            if level not in settings.CASE_LEVEL_LIST:
-                logger.warning(f"{func_name} 使用非规范的用例级别 {level}")
-                if settings.STRICT_MARKS:
-                    continue
+
             case_data["level"] = level
             new_marks = marks.copy()
             new_marks.append(level)
@@ -449,6 +442,14 @@ def pytest_generate_tests(metafunc):
             if not keyword_flag or not mark_flag:
                 continue
 
+            if not is_subset:
+                logger.warning(f"{node_id} 使用非规范的用例标签:{list(diff)}")
+                if settings.STRICT_MARKS:
+                    return
+            if level not in settings.CASE_LEVEL_LIST:
+                logger.warning(f"{node_id} 使用非规范的用例级别 {level}")
+                if settings.STRICT_MARKS:
+                    continue
             try:
                 deep_copied_case_data = copy.deepcopy(case_data)
                 # 剔除标记disable的字段
@@ -468,27 +469,32 @@ def pytest_generate_tests(metafunc):
 
         metafunc.parametrize("data", case_data_list, ids=ids, scope="function")
     else:
-        if not case_common.get("ignore"):
-            case_data["_scenario"] = {"data": {}}
-            case_data["_ignore_failed"] = case_common.get("ignore_failed", settings.GLOBAL_IGNORE_FAILED)
-            level = case_data.get("level", settings.DEFAULT_CASE_LEVEL)
-            if level not in settings.CASE_LEVEL_LIST:
-                logger.warning(f"{func_name}使用非规范的用例级别 {level}")
-                if settings.STRICT_MARKS:
-                    return
-            case_data["level"] = level
-            new_marks = marks.copy()
-            new_marks.append(level)
-            # 用例加mark标签
-            case_data["_marks"] = new_marks
-            # mark标记
-            mark_flag = match_mark(mark_expr, new_marks)
-            # 用例路径匹配不到关键词,或者标签匹配不到用例，跳过该用例加载
-            if not keyword_flag or not mark_flag:
+        if case_common.get("ignore"):
+            return
+        case_data["_scenario"] = {"data": {}}
+        case_data["_ignore_failed"] = case_common.get("ignore_failed", settings.GLOBAL_IGNORE_FAILED)
+        level = case_data.get("level", settings.DEFAULT_CASE_LEVEL)
+        case_data["level"] = level
+        new_marks = marks.copy()
+        new_marks.append(level)
+        # 用例加mark标签
+        case_data["_marks"] = new_marks
+        # mark标记
+        mark_flag = match_mark(mark_expr, new_marks)
+        # 用例路径匹配不到关键词,或者标签匹配不到用例，跳过该用例加载
+        if not keyword_flag or not mark_flag:
+            return
+        if not is_subset:
+            logger.warning(f"{node_id} 使用非规范的用例标签:{list(diff)}")
+            if settings.STRICT_MARKS:
+                return
+        if level not in settings.CASE_LEVEL_LIST:
+            logger.warning(f"{node_id} 使用非规范的用例级别 {level}")
+            if settings.STRICT_MARKS:
                 return
-        # 进行参数化生成用例
         logger.info(f"{node_id}::{case_data.get('title')}#1")
         case_data_list = [case_data]
+        # 进行参数化生成用例
         metafunc.parametrize("data", case_data_list, ids=[f'{case_data.get("title")}#1'], scope="function")
 
 
@@ -607,10 +613,8 @@ def sort(case_items):
 
 def pytest_collection_finish(session):
     """获取最终排序后的 items 列表"""
-    # 过滤掉item名称是test_setup或test_teardown的
     logger.info(f"共收集到 {len(session.items)} 个测试用例")
-    if len(session.items) == 0:
-        pytest.exit(0)
+    # 过滤掉item名称是test_setup或test_teardown的
     session.items = [item for item in session.items if item.name not in ["test_setup", "test_teardown"]]
 
     # 1. 筛选出带井号 名称带'#' 的item，并记录原始索引
@@ -647,8 +651,29 @@ def pytest_collection_finish(session):
 
 
 def pytest_runtestloop(session):
+    # 统一登录账号
     _FRAMEWORK_CONTEXT.set(key="_http", value=login())
 
+    # 执行前置脚本
+    app = CONTEXT.get("app")
+    app_handlers = getattr(settings, "APP_START_HANDLER_CLASSES", {})
+    if app:
+        handlers = app_handlers.get(app) or []
+    else:
+        handlers = [h for value in app_handlers.values() for h in value] or []
+    global_handlers = getattr(settings, "GLOBAL_START_HANDLER_CLASSES", [])
+    global_handlers.extend(handlers)
+    handlers = global_handlers
+    for handler in handlers:
+        try:
+            module_path, class_name = handler.rsplit(".", 1)
+            cls = getattr(importlib.import_module(module_path), class_name)
+            cls().run()
+        except Exception as e:
+            logger.error(str(e))
+            traceback.print_exc()
+            pytest.exit(ExitCode.GLOBAL_SCRIPT_ERROR)
+
 
 def pytest_runtest_setup(item):
     allure.dynamic.sub_suite(item.allure_suite_mark)
@@ -686,14 +711,13 @@ def pytest_runtest_call(item):
         if item.funcargs.get("setup_success") is False:
             pytest.skip(f"test_setup execute error")
         # 判断上一个用例是否执行失败，如果上一个用例执行失败，则主动标记用例执行失败，不会执行用例（解决场景性用例，有一个失败则后续用例判为失败）
-
         index = item.session.items.index(item)
         pattern = re.compile(r'^(?P<prefix>.*)::[^:\[\]]+\[.*#(?P<index>\d+)\]$')
         current_match = pattern.match(item.nodeid)
         current_cls_name = current_match.group('prefix')
         current_index = current_match.group('index')
         prev_item = item.session.items[index - 1]
-        prev_match = pattern.match(item.nodeid)
+        prev_match = pattern.match(prev_item.nodeid)
         prev_cls_name = prev_match.group("prefix")
         prev_index = prev_match.group("index")
         # 确保是同一个类,并且索引相同
@@ -711,13 +735,11 @@ def pytest_runtest_call(item):
     # 获取原始测试数据
     origin_data = item.funcargs.get("data")
     logger.info(f"执行用例: {item.nodeid}")
-    # # 对原始请求数据进行渲染替换
-    # rendered_data = RenderData(origin_data).render()
     # 函数式测试用例添加参数data, belong_app
     http = item.funcargs.get("http")
     item.funcargs["data"] = item.instance.data = Box(origin_data)
-    item.funcargs["scenario"] = item.instance.scenario = Box(
-        convert_numbers_to_decimal(origin_data.get("_scenario")))
+    item.funcargs["scenario"] = item.instance.scenario = Box(json.loads(json.dumps(
+        convert_numbers_to_decimal(origin_data.get("_scenario")))))
     _belong_app = origin_data.get("_belong_app")
     item.funcargs["belong_app"] = item.instance.belong_app = _belong_app
     item.funcargs["config"] = item.instance.config = CONFIG
