@@ -51,21 +51,61 @@ class MysqlDB:
         )
 
     @safe_mysql_call
-    def query(self, sql):
+    def query(self, sql, log=True):
         """查询，返回结果"""
         connection = self.pool.connection()  # 获取一个连接
         cursor = connection.cursor(pymysql.cursors.DictCursor)
         try:
             cursor.execute(sql)
-            logger.info(f"执行SQL: {sql}")
+            if log:
+                logger.info(f"执行SQL: {sql}")
             result = cursor.fetchall()
             if len(result) == 1:
                 result = result[0]
             elif len(result) == 0:
                 result = None
             if isinstance(result, dict) or isinstance(result, list):
-                logger.info(f"SQL执行结果: {json.dumps(result, default=MysqlDB.custom_serializer)}")
+                if log:
+                    logger.info(f"SQL执行结果: {json.dumps(result, default=MysqlDB.custom_serializer)}")
             else:
+                if log:
+                    logger.info(f"SQL执行结果: {result}")
+            return result
+
+        finally:
+            cursor.close()  # 关闭游标
+            connection.close()  # 将连接返回到连接池
+
+    @safe_mysql_call
+    def insert(self, sql, log=True):
+        """修改，新增，删除"""
+        connection = self.pool.connection()  # 获取一个连接
+        cursor = connection.cursor(pymysql.cursors.DictCursor)
+        try:
+            cursor.execute(sql)
+            if log:
+                logger.info(f"执行SQL: {sql}")
+            connection.commit()
+            inserted_id = cursor.lastrowid
+            if log:
+                logger.info(f"插入的记录的主键ID: {inserted_id}")
+            return inserted_id
+
+        finally:
+            cursor.close()  # 关闭游标
+            connection.close()  # 将连接返回到连接池
+
+    @safe_mysql_call
+    def execute(self, sql, log=True):
+        """修改，新增，删除"""
+        connection = self.pool.connection()  # 获取一个连接
+        cursor = connection.cursor(pymysql.cursors.DictCursor)
+        try:
+            result = cursor.execute(sql)
+            if log:
+                logger.info(f"执行SQL: {sql}")
+            connection.commit()
+            if log:
                 logger.info(f"SQL执行结果: {result}")
             return result
 
@@ -74,47 +114,17 @@ class MysqlDB:
             connection.close()  # 将连接返回到连接池
 
     @safe_mysql_call
-    def insert(self, sql):
-        """修改，新增，删除"""
-        connection = self.pool.connection()  # 获取一个连接
-        cursor = connection.cursor(pymysql.cursors.DictCursor)
-        try:
-            result = cursor.execute(sql)
-            connection.commit()
-            inserted_id = cursor.lastrowid
-            logger.info(f"插入的记录的主键ID: {inserted_id}")
-            return inserted_id
-
-        finally:
-            cursor.close()  # 关闭游标
-            connection.close()  # 将连接返回到连接池
-
-    @safe_mysql_call
-    def execute(self, sql):
-        """修改，新增，删除"""
-        connection = self.pool.connection()  # 获取一个连接
-        cursor = connection.cursor(pymysql.cursors.DictCursor)
-        try:
-            result = cursor.execute(sql)
-            logger.info(f"执行SQL: {sql}")
-            connection.commit()
-            logger.info(f"SQL执行结果: {result}")
-            return result
-
-        finally:
-            cursor.close()  # 关闭游标
-            connection.close()  # 将连接返回到连接池
-
-    @safe_mysql_call
-    def executemany(self, sql, data):
+    def executemany(self, sql, data, log=True):
         """修改，新增，删除"""
         connection = self.pool.connection()  # 获取一个连接
         cursor = connection.cursor(pymysql.cursors.DictCursor)
         try:
             cursor.executemany(sql, data)
-            logger.info(f"执行SQL: {sql}")
+            if log:
+                logger.info(f"执行SQL: {sql}")
             connection.commit()
-            logger.info(f"{cursor.rowcount} records inserted.")
+            if log:
+                logger.info(f"{cursor.rowcount} records inserted.")
 
         finally:
             cursor.close()  # 关闭游标
